@@ -18,6 +18,8 @@ ChemicalBasis::ChemicalBasis()
     setAdsorptionLayerWidth(1.0e-10);
     setAdsorptionLayerFactors(std::vector<double>(1, 1.0));
     setSnyderApproximation(false);
+    setSpecialRodModel(true);
+	setNeglectPartiallyDesorbedStates(false);
 }
 
 ChemicalBasis::ChemicalBasis(PredefinedChemicalBasis predefinedChemicalBasisId)
@@ -184,6 +186,26 @@ void ChemicalBasis::setSnyderApproximation(bool flag)
     mSnyderApproximation = flag;
 }
 
+bool ChemicalBasis::specialRodModel() const 
+{
+    return mSpecialRodModel;
+}
+
+void ChemicalBasis::setSpecialRodModel(bool flag) 
+{
+    mSpecialRodModel = flag;
+}
+
+bool ChemicalBasis::neglectPartiallyDesorbedStates() const
+{
+	return mNeglectPartiallyDesorbedStates;
+}
+
+void ChemicalBasis::setNeglectPartiallyDesorbedStates(bool flag)
+{
+	mNeglectPartiallyDesorbedStates = flag;
+}
+
 double ChemicalBasis::firstSolventDensity() const
 {
     return mFirstSolventDensity;
@@ -195,7 +217,7 @@ void ChemicalBasis::setFirstSolventDensity(double newFirstSolventDensity)
     if (newFirstSolventDensity < 0.0)
     {
         throw ChemicalBasisException(
-            "The density must have a not-negative value.");
+            "The density must have a non-negative value.");
     }
     mFirstSolventDensity = newFirstSolventDensity;
 }
@@ -228,7 +250,7 @@ void ChemicalBasis::setFirstSolventAverageMass(
     if (newFirstSolventAverageMass < 0.0)
     {
         throw ChemicalBasisException(
-            "The average mass must have a not-negative value.");
+            "The average mass must have a non-negative value.");
     }
     mFirstSolventAverageMass = newFirstSolventAverageMass;
 }
@@ -274,6 +296,8 @@ ChemicalBasis ChemicalBasis::setPredefinedChemicalBasis(
             setMonomerLength(10.0);
             setKuhnLength(10.0);
             setSnyderApproximation(false);
+            setSpecialRodModel(true);
+			setNeglectPartiallyDesorbedStates(false);
 
             clearChemicalGroups();
             addChemicalGroup(ChemicalGroup ("Alanine",
@@ -405,22 +429,26 @@ ChemicalBasis ChemicalBasis::setPredefinedChemicalBasis(
                                            "H-",
                                            -1.69,
                                            1.0079,
-                                           1.00782));
+                                           1.00782,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("N-terminal acetyl",
                                            "Ac-",
                                            0.0,
                                            43.0452,
-                                           43.01839));
+                                           43.01839,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("C-terminal carboxyl group",
                                            "-OH",
                                            -0.03,
                                            17.0073,
-                                           17.00274));
+                                           17.00274,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("C-terminal amide",
                                            "-NH2",
                                            0.0,
                                            16.0226,
-                                           16.01872));
+                                           16.01872,
+                                           0.0));
             break;
         }
 
@@ -439,6 +467,8 @@ ChemicalBasis ChemicalBasis::setPredefinedChemicalBasis(
             setSecondSolventAverageMass(41.05);
             setSecondSolventBindEnergy(2.4);
             setSnyderApproximation(false);
+            setSpecialRodModel(true);
+			setNeglectPartiallyDesorbedStates(false);
 
             clearChemicalGroups();
             addChemicalGroup(ChemicalGroup ("Alanine",
@@ -570,22 +600,26 @@ ChemicalBasis ChemicalBasis::setPredefinedChemicalBasis(
                                            "H-",
                                            -2.39,
                                            1.0079,
-                                           1.00782));
+                                           1.00782,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("N-terminal acetyl",
                                            "Ac-",
                                            -0.05,
                                            43.0452,
-                                           43.01839));
+                                           43.01839,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("C-terminal carboxyl group",
                                            "-OH",
                                            1.02,
                                            17.0073,
-                                           17.00274));
+                                           17.00274,
+                                           0.0));
             addChemicalGroup(ChemicalGroup("C-terminal amide",
                                            "-NH2",
                                            0.55,
                                            16.0226,
-                                           16.01872));
+                                           16.01872,
+                                           0.0));
             break;
         }
     }
